%define module  mpi4py
# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python3_sitearch}/.*\\.so

Summary:       MPI for Python
Name:          python-%{module}
Version:       3.1.3
Release:       %mkrel 1
Source0:       https://bitbucket.org/mpi4py/mpi4py/downloads/%{module}-%{version}.tar.xz
License:       Public Domain
Group:         Development/Python
Url:           https://bitbucket.org/mpi4py
BuildRequires: openmpi
BuildRequires: pkgconfig(ompi)
BuildRequires: pkgconfig(zlib)
BuildRequires: pkgconfig(python3)
BuildRequires: python3-cython

%description
MPI for Python provides bindings of the Message Passing Interface
(MPI) standard for the Python programming language, allowing any
Python program to exploit multiple processors.

This package is constructed on top of the MPI-1/2 specifications and
provides an object oriented interface which closely follows MPI-2 C++
bindings. It supports point-to-point (sends, receives) and collective
(broadcasts, scatters, gathers) communications of any picklable Python
object, as well as optimized communications of Python object exposing
the single-segment buffer interface (NumPy arrays, builtin
bytes/string/array objects).

%package doc
Summary:    Documentation for mpi4py
Group:      Development/Python
BuildArch:  noarch

%description doc
This package contains documentation for MPI for Python.

%package -n python3-%{module}
Summary:    Python 3 bindings of the Message Passing Interface (MPI)
Group:      Development/Python
Requires:   openmpi
%{?python_provide:%python_provide python3-%{module}}

%description -n python3-%{module}
MPI for Python provides bindings of the Message Passing Interface
(MPI) standard for the Python programming language, allowing any
Python 3 program to exploit multiple processors.

This package is constructed on top of the MPI-1/2 specifications and
provides an object oriented interface which closely follows MPI-2 C++
bindings. It supports point-to-point (sends, receives) and collective
(broadcasts, scatters, gathers) communications of any picklable Python
object, as well as optimized communications of Python object exposing
the single-segment buffer interface (NumPy arrays, builtin
bytes/string/array objects).

%package -n python3-%{module}-devel
Summary:    mpi4py headers
Group:      Development/Python
Requires:   python3-%{module} = %{version}-%{release}

%description -n python3-%{module}-devel
This package contains header files needed to develop modules in C or
Fortran that can interact with mpi4py.

%prep
%setup -q -n %{module}-%{version}
# delete docs/source
# this is just needed to generate docs/*
rm -r docs/source

# work around "wrong-file-end-of-line-encoding"
for file in $(find | grep runtests.bat); do
    sed -i 's/\r//' $file
done

%build
export CFLAGS="-Wno-error=format-security" 
%py3_build

%install
%py3_install
rm -f %{buildroot}%{python3_sitearch}/mpi4py/mpi.cfg

%files doc
%doc test/ demo/ docs/usrman docs/apiref

%files -n python3-%{module}
%{python3_sitearch}/%{module}*
%exclude %{python3_sitearch}/%{module}/include/

%files -n python3-%{module}-devel
%{python3_sitearch}/%{module}/include/

%changelog
* Mon Aug 08 2022 TerryN <terryn94 at gmail.com> - 3.1.3-1pclos2022
- update and rebuild for python 3.10

* Wed Feb 12 2020 onkelho <oh.quait at gmail.com> - 3.0.1-1pclos2020
- initial build

